@@ -1,6 +1,7 @@
-import tensorflow as tf
 from typing import Tuple
 
+import tensorflow as tf
+
 
 def efficientnetb0(input_shape: Tuple[int, int, int]) -> tf.keras.Model:
 
@@ -11,6 +12,7 @@ def efficientnetb0(input_shape: Tuple[int, int, int]) -> tf.keras.Model:
     model = tf.keras.Model(inputs=model.input, outputs=outputs, name="EfficientNetB0")
     return model
 
+
 def LivenessHead(
     num_classes: int = 1,
     classifier_activation: str = "softmax",
@@ -40,17 +42,14 @@ def LivenessHead(
 
 
 def build_classifier(backbone, head) -> tf.keras.Model:
-    """:arg
-
-    """
+    """:arg"""
     output = head(backbone.output)
     model = tf.keras.Model(inputs=backbone.input, outputs=output, name=backbone.name)
 
     return model
 
 
-if __name__ == '__main__':
-    # backbone = efficientnetb0((224, 224, 3))
+if __name__ == "__main__":
     head = LivenessHead(num_classes=1)
     head.summary()
     layer = head.get_layer(index=-2)
@@ -58,12 +57,7 @@ if __name__ == '__main__':
     assert layer.__class__.__name__ != "Dropout"
     print(len(layer1.output_shape))
     print(layer1.get_config())
-    print(layer1.get_config()['activation'] == 'softmax' or layer1.get_config()['activation'] == 'sigmoid')
-    print(layer1.get_config()['activation'] == 'softmax')
-    print(layer1.get_config()['activation'] == 'sigmoid')
-    print(output)
-
-
-
-
-
+    print(
+        layer1.get_config()["activation"] == "softmax"
+        or layer1.get_config()["activation"] == "sigmoid"
+    )
