@@ -1,3 +1,3 @@
-# __all__ = ["load_data", "load_data_fit"]
+__all__ = ["load_data", "load_data_fit"]
 
 from .dataset_generator import load_data, load_data_fit
